;;;
;;; draw-function.scm
;;; update to TinyScheme
;;; require Gimp 2.4.1 or last
;;;
;;;  Arch. Giuseppe Conte <http://xoomer.alice.it/lwcon/>
;;;
;;; This program is free software; you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 2 of the License, or
;;; (at your option) any later version.
;;; 
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;; 
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

;;; Define the function:

(define (script-fu-draw-function inImage inLayer Curva xa ya Radius Inclination Length deltaX inAngle scala)

	(let* (	(segment)
					(segment (make-vector 4)) 
					(npoint)
					(beta)
					(gamma)
					(alfa)
					(kappa)
					(xzero)
					(yzero)
				)
	
		(set! npoint 4)
		(set! beta (* Inclination (/ *pi* 180)))
		(set! gamma (* inAngle (/ *pi* 180)))
		(set! alfa (+ gamma))
		(set! kappa (/ deltaX Radius) )
		(set! xzero 0)

    	(gimp-undo-push-group-start inImage)	
    							
	     	(while (<= xzero Length)
	     	
		(if (= Curva 0)	(set! yzero (* scala (- (* Radius (sin alfa))))) (set! yzero (* scala (- (* Radius (cos alfa)))))  )
				     				
  			(vector-set! segment 0 (+ (- (* xzero (cos beta)) (* yzero (sin beta))) xa))
  			(vector-set! segment 1 (+ (+ (* xzero (sin beta)) (* yzero (cos beta))) ya) )
  			
  			(set! alfa (+ alfa kappa))
				(set! xzero (+ xzero deltaX))	     		

		(if (= Curva 0)	(set! yzero (* scala (- (* Radius (sin alfa)))) ) (set! yzero (* scala (- (* Radius (cos alfa)))))  )
					  			
  			(vector-set! segment 2 (+ (- (* xzero (cos beta)) (* yzero (sin beta))) xa))
  			(vector-set! segment 3 (+ (+ (* xzero (sin beta)) (* yzero (cos beta))) ya))

   
		(gimp-pencil inLayer npoint segment)

  	  	(gimp-displays-flush)
  	  
				); end while
    );let

    	(gimp-undo-push-group-end inImage)		
   	(gimp-displays-flush)
   	  	   	       	
) ;;def


(script-fu-register
 "script-fu-draw-function"
 _"<Image>/_ATG/_Curves/_Draw Sine or Cosine"
 "Draw trigonometrical curve sine or cosine."
 "Arch. Giuseppe Conte <http://xoomer.alice.it/lwcon/>"
 "2007, Giuseppe Conte"
 "10 dicembre 2007 - 72026 San Pancrazio Salentino (BR) - Italy"
 "RGB* GRAY* INDEXED*"
 SF-IMAGE "The Image" 0
 SF-DRAWABLE "The Layer" 0
 SF-OPTION "Curva" '("Sine" "Cosine")
 SF-ADJUSTMENT "Xa" '(0 0 9999 1 10 0 1)
 SF-ADJUSTMENT "Ya" '(0 0 9999 1 10 0 1)
 SF-ADJUSTMENT "Radius" '(10 0 9999 1 10 0 1)
 SF-ADJUSTMENT "Inclination" '(0 -9999 9999 1 10 0 1)
 SF-ADJUSTMENT "Length" '(100 0 9999 1 10 0 1)
 SF-ADJUSTMENT "Increment" '(1 0 9999 1 10 0 1)
 SF-ADJUSTMENT "Initial Angle" '(0 -9999 9999 1 10 0 1)
 SF-ADJUSTMENT "Deformation" '(1 -9999 9999 0.1 10 1 0)
)


;;SF-ADJUSTEMENT "Etichetta" (valore_iniziale valore_piu_basso valore_piu_alto velocita_incremento 10? decimali tipo_casella_[0,1])